# django-bootstrap4-components
Django Bootstrap 4 components

## Quick start

1. Add "bootstrap_components" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'bootstrap_components',
    ]

2. TODO: Write this

3. ???

4. Profit
